==> mgb-0.6.7.tar.bz2: language/lang_turkish_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================================= //
	// lang_main.php - Turkish 1.0 by Mustafa Dündar //
	// ============================================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// strings of index.php
	$lang['install_directory_exists'] = "Kurulum dizini silinmedi.<br>Keni güvenliðin için þimdi yap!<br>Güncelleþtirmeden sonra çalýþtýrmayý <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> unutma!";
	$lang['new_entry'] = "Kayýt";
	$lang['new_entry_descr'] = "Burada bir Ziyaretci Defterine yazabilirsin";
	$lang['contact'] = "Ýletiþim";
	$lang['contact_descr'] = "Sen burada Yönetici ile iliþgiye girebilirsin";
	$lang['adminpanel'] = "Yönetim";
	$lang['adminpanel_descr'] = "Oturum açmak için";
	$lang['entry'] = "Giriþ";
	$lang['entries'] = "Giriþler";
	$lang['no_entries'] = "Malesef hiç bir <br>giriþ yapýlmamýþtýr.";
	$lang['entries_on_pages'] = "Giriþler {PAGES} Sayfa";
	$lang['page_first'] = "Ýlk sayfaya ";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Bir Sayfa ileri git";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Son Sayfa";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Bir sayfa geri git";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor']	= "Bu giriþe doðrudan git";
	$lang['from'] = "dan";
	$lang['at'] = "için";
	$lang['oclock']	= "Saat";
	$lang['comment'] = "Yorum";
	$lang['email_yes'] = "eMail {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} Ziyaretçi Defterinden e-Posta almak istemiyorsanýz.";
	$lang['hp_of'] = "Anasayfa {ENTRY_NAME}";
	$lang['gravatar'] = "Gravator {ENTRY_NAME}";

	// strings of newentry.php
	$lang['name'] = "Adýn:";
	$lang['city'] = "Oturduðun yer:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Ýnternet Sitesi:";
	$lang['message'] = "Senin Mesajýn:";
	$lang['necessary_fields'] = "[ (*) iþaretli yerleri doldurmanýz gerekir ]";
	$lang['user_notification'] = "Eðer bir giriþ veya Mesaj yazýldýðýnda e-Posta ile haber verilir.";
	$lang['user_show_email'] = "Ýletiþim Formu aracýlýðý ile bana diger kullanýcýlardan e-Posta yazmasý için izin ver. Spam önlemek için benim e-Posta adresimi gösterme.";
	$lang['send'] = "Kayýt";
	$lang['preview'] = "Önizleme";
	$lang['errormessage1'] = "Bir mesaj girin!";
	$lang['errormessage2'] = "Geçerli bir eMail adresi girin!";
	$lang['errormessage3'] = "Lütfen isminizi giriniz!";
	$lang['errormessage4'] = "geçerli bir <br>eMail adresi deðil!";
	$lang['errormessage5'] = "geçerli býr <br>ICQ numarasý deðil!";
	$lang['errormessage6'] = "IP Blogu bir daha giriþe yasaklý!";
	$lang['errormessage7'] = "Güvenlik kodu yanlýþ veya girilmedi!";
	$lang['errormessage8'] = "Bu Kullanýcý e-Posta almak istemiyor!";
	$lang['errormessage9'] = "E-Posta giderken bir hata oluþtu!";
	$lang['errormessage10'] = "Spamprotection: The formular was sent too fast. Please wait {TIME_LOCK_REST} more seconds. Thank you.";
	$lang['security_code'] = "Güvenlik Kodu";
	$lang['captcha_what_is_that'] = "Bu nedir?";
	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Yeni bir giriþ otomatik kayýtlarý engellemek için bir güvenlik kodu gerektirir. Lütfen bütün harfleri büyük gir. Eðer Kod okunamzise boþ yaz ''Eintragen''. Yeni bir Kod oluþturulur. Önceki verdiðin deðerler kalýr. Eðer yeni Cod oluþmazise saðtarafta ''Aktualisieren'' bas.";
	$lang['back_to_mainpage'] = "Ana Sayfaya geri dön";
	$lang['back'] = "Geri";
	$lang['entry_success_mod'] = "Yorum baþarýyla kaydedildi. <br>O, Yönetici tarafýndan incelenir, sonra yayýnlanýr.";
	$lang['entry_success'] = "Yorum baþarýyla kaydedildi. Bunu hemen görebilirsiniz.";
	$lang['forwarding'] = "5 saniye içinde otamatik olarak yönlendirileceksiniz. Deðilse Anasayfaya ''Geri'' bas.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Yað";
	$lang['bbcode_help_italic'] = "Ýtalik";
	$lang['bbcode_help_url'] = "Baðlantý";
	$lang['bbcode_textsize'] = "Yazý tipi boyutu";
	$lang['bbcode_extrasmall'] = "Minik";
	$lang['bbcode_small'] = "Küçük";
	$lang['bbcode_default'] = "Standart";
	$lang['bbcode_big'] = "Birleþik";
	$lang['bbcode_extrabig'] = "Kocaman";
	$lang['bbcode_textcolor'] = "Yazý tipi rengi";
	$lang['bbcode_help_size'] = "Yayý tipi boyutu";
	$lang['smileys'] = "Smilies:";
	$lang['sendmail_admin_title'] = "Yeni giriþ '{NAME}'";
	$lang['sendmail_user_title'] = "Kayýt {DOMAIN}";

	// strings of email.php
	$lang['email_name'] = "Senin Ýsmin:";
	$lang['email_email'] = "Senin eMail:";
	$lang['email_message'] = "Senin Haberin:";
	$lang['email_sent_to'] = "Bu eMail ona gönderilecektir:";
	$lang['email_send'] = "gönder";
	$lang['email_caption'] = "e-Posta '{NAME}' Ziyaretçi Defteri üzerine {DOMAIN} den";
	$lang['email_sender'] = "Gönderen:";
	$lang['email_receiver'] = "Alýcý:";
	$lang['email_from'] = "üzerinde:";
	$lang['email_sendcopytome'] = "Bu e-Postanin bir kopyasýný istiyorum.";
	$lang['email_success'] = "Senin e-Postan kullanýcýya baþarýyla gönderilmiþtir.";
	$lang['email_fail'] = "E-Posta gönderilemedi. Posta sunucusu ile ilgili bir sorun olabilir.";
?>

==> mgb-0.6.7.1.tar.bz2: language/lang_turkish_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================================= //
	// lang_main.php - Turkish 1.0 by Mustafa Dündar //
	// ============================================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// strings of index.php
	$lang['install_directory_exists'] = "Kurulum dizini silinmedi.<br>Keni güvenliðin için þimdi yap!<br>Güncelleþtirmeden sonra çalýþtýrmayý <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> unutma!";
	$lang['new_entry'] = "Kayýt";
	$lang['new_entry_descr'] = "Burada bir Ziyaretci Defterine yazabilirsin";
	$lang['contact'] = "Ýletiþim";
	$lang['contact_descr'] = "Sen burada Yönetici ile iliþgiye girebilirsin";
	$lang['adminpanel'] = "Yönetim";
	$lang['adminpanel_descr'] = "Oturum açmak için";
	$lang['entry'] = "Giriþ";
	$lang['entries'] = "Giriþler";
	$lang['no_entries'] = "Malesef hiç bir <br>giriþ yapýlmamýþtýr.";
	$lang['entries_on_pages'] = "Giriþler {PAGES} Sayfa";
	$lang['page_first'] = "Ýlk sayfaya ";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Bir Sayfa ileri git";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Son Sayfa";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Bir sayfa geri git";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor']	= "Bu giriþe doðrudan git";
	$lang['from'] = "dan";
	$lang['at'] = "için";
	$lang['oclock']	= "Saat";
	$lang['comment'] = "Yorum";
	$lang['email_yes'] = "eMail {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} Ziyaretçi Defterinden e-Posta almak istemiyorsanýz.";
	$lang['hp_of'] = "Anasayfa {ENTRY_NAME}";
	$lang['gravatar'] = "Gravator {ENTRY_NAME}";

	// strings of newentry.php
	$lang['name'] = "Adýn:";
	$lang['city'] = "Oturduðun yer:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Ýnternet Sitesi:";
	$lang['message'] = "Senin Mesajýn:";
	$lang['necessary_fields'] = "[ (*) iþaretli yerleri doldurmanýz gerekir ]";
	$lang['user_notification'] = "Eðer bir giriþ veya Mesaj yazýldýðýnda e-Posta ile haber verilir.";
	$lang['user_show_email'] = "Ýletiþim Formu aracýlýðý ile bana diger kullanýcýlardan e-Posta yazmasý için izin ver. Spam önlemek için benim e-Posta adresimi gösterme.";
	$lang['user_accept_akismet_service'] = "This entry will be checked by the plugin 'Akismet' on spam. I am aware of the circumstance, that personal data of me will be sent to a server in the United States of America and i do accept this.";
	$lang['send'] = "Kayýt";
	$lang['preview'] = "Önizleme";
	$lang['errormessage1'] = "Bir mesaj girin!";
	$lang['errormessage2'] = "Geçerli bir eMail adresi girin!";
	$lang['errormessage3'] = "Lütfen isminizi giriniz!";
	$lang['errormessage4'] = "geçerli bir <br>eMail adresi deðil!";
	$lang['errormessage5'] = "geçerli býr <br>ICQ numarasý deðil!";
	$lang['errormessage6'] = "IP Blogu bir daha giriþe yasaklý!";
	$lang['errormessage7'] = "Güvenlik kodu yanlýþ veya girilmedi!";
	$lang['errormessage8'] = "Bu Kullanýcý e-Posta almak istemiyor!";
	$lang['errormessage9'] = "E-Posta giderken bir hata oluþtu!";
	$lang['errormessage10'] = "Spamprotection: The formular was sent too fast. Please wait {TIME_LOCK_REST} more seconds. Thank you.";
	$lang['errormessage11'] = "The Akismet data privacy agreement was not accepted. It MUST be accepted to save the entry.";
	$lang['security_code'] = "Güvenlik Kodu";
	$lang['captcha_what_is_that'] = "Bu nedir?";
	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Yeni bir giriþ otomatik kayýtlarý engellemek için bir güvenlik kodu gerektirir. Lütfen bütün harfleri büyük gir. Eðer Kod okunamzise boþ yaz ''Eintragen''. Yeni bir Kod oluþturulur. Önceki verdiðin deðerler kalýr. Eðer yeni Cod oluþmazise saðtarafta ''Aktualisieren'' bas.";
	$lang['back_to_mainpage'] = "Ana Sayfaya geri dön";
	$lang['back'] = "Geri";
	$lang['entry_success_mod'] = "Yorum baþarýyla kaydedildi. <br>O, Yönetici tarafýndan incelenir, sonra yayýnlanýr.";
	$lang['entry_success'] = "Yorum baþarýyla kaydedildi. Bunu hemen görebilirsiniz.";
	$lang['forwarding'] = "5 saniye içinde otamatik olarak yönlendirileceksiniz. Deðilse Anasayfaya ''Geri'' bas.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Yað";
	$lang['bbcode_help_italic'] = "Ýtalik";
	$lang['bbcode_help_url'] = "Baðlantý";
	$lang['bbcode_textsize'] = "Yazý tipi boyutu";
	$lang['bbcode_extrasmall'] = "Minik";
	$lang['bbcode_small'] = "Küçük";
	$lang['bbcode_default'] = "Standart";
	$lang['bbcode_big'] = "Birleþik";
	$lang['bbcode_extrabig'] = "Kocaman";
	$lang['bbcode_textcolor'] = "Yazý tipi rengi";
	$lang['bbcode_help_size'] = "Yayý tipi boyutu";
	$lang['smileys'] = "Smilies:";
	$lang['sendmail_admin_title'] = "Yeni giriþ '{NAME}'";
	$lang['sendmail_user_title'] = "Kayýt {DOMAIN}";

	// strings of email.php
	$lang['email_name'] = "Senin Ýsmin:";
	$lang['email_email'] = "Senin eMail:";
	$lang['email_message'] = "Senin Haberin:";
	$lang['email_sent_to'] = "Bu eMail ona gönderilecektir:";
	$lang['email_send'] = "gönder";
	$lang['email_caption'] = "e-Posta '{NAME}' Ziyaretçi Defteri üzerine {DOMAIN} den";
	$lang['email_sender'] = "Gönderen:";
	$lang['email_receiver'] = "Alýcý:";
	$lang['email_from'] = "üzerinde:";
	$lang['email_sendcopytome'] = "Bu e-Postanin bir kopyasýný istiyorum.";
	$lang['email_success'] = "Senin e-Postan kullanýcýya baþarýyla gönderilmiþtir.";
	$lang['email_fail'] = "E-Posta gönderilemedi. Posta sunucusu ile ilgili bir sorun olabilir.";
?>
